//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                       (c) 1997 European Space Agency
//
//---------------------------------------------------------------------------
//
//	ExprConstructor.h:	--- a Qt widget with a line edit widget
//
//	DESCRIPTION:
//		A new Qt widget class is declared - faciliates the construction
//		of a boolean expression for row filtering.
//
//	CHANGE HISTORY:
//		UL, 1998-11-05: 1.0.0: - first version
//		UL, 2000-05-10: 1.1.0: - constructor takes initial selection
//								 expression as argument (optional)
//		UL, 2000-11-07: 1.2.0: - various updates
//
//	AUTHOR:
//		U. Lammers (UL), Thu Nov  5 10:01:37 MET 1998
//
//	$Header: /usr/local/cvs/sasdev/task_devel/packages/xmmselect/src/ExprConstructor.h,v 1.9 2002/07/11 16:08:13 ulammers Exp $
//

#ifndef EXPR_CONSTRUCTOR_H
#define EXPR_CONSTRUCTOR_H

#include <qdialog.h>
#include <qgroupbox.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qradiobutton.h>
#include <qlayout.h>
#include <qframe.h>
#include <string>

#include "Preferences.h"

class QMultiLineEdit;
class QWidget;

class ExpressionConstructor : public QGroupBox {
	Q_OBJECT

public:
	ExpressionConstructor(QWidget *parent, const char *name,
						  const std::string &expr = "");

	string expression() const;

	void manageSelectionExpressionDialog(const std::string &expr,
							 const std::string &message = "",
							 const std::string &title =	"Select expression");

	enum AppendMode { AND, OR, OR_IF_SAME_SENDER };
	void appendExpression(const std::string &expr, AppendMode appendMode = AND,
						  const std::string &sender = "UNKNOWN");

	void fontChange(const QFont&);

	~ExpressionConstructor();

private slots:
	void clear();
	void import();
	void prefSelSelected(const std::string &prefPath,
						 const PreferenceValue &value);

private:
	//	data members
	static const char *const prefSelectionName = "PrefSelections";

	QMultiLineEdit	*_exprEdit;
	string		_lastSender;
	unsigned	_exprCount;
	string		_lastExpression;
}; // ExpressionConstructor


class SelectionExpressionDialog : public QDialog {
	Q_OBJECT

public:
	SelectionExpressionDialog(QWidget *parent, const char *name,
							  const std::string &message,
							  const std::string &expr);

	~SelectionExpressionDialog();

private:
	//	data
	QBoxLayout		*_vbox, *_hboxedit, *_hboxbutt;
	QPushButton		*_ok, *_cancel;
	QMultiLineEdit	*_exprEdit;

	//	method
	void accept();
};

#endif

