//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//	XmmSelectGui.h:	--- classes related to XmmSelect GUI
//
//	DESCRIPTION:
//		Classes related to the XmmSlelect GUI
//
//	CHANGE HISTORY:
//		UL, 1998-10-22: 1.0.0: - first version
//		UL, 1999-05-06: 1.1.0: - various changes; prepared usage of
//								 tabcalc task for creating new columns
//		UL, 1999-09-22: 1.2.0: - brought in line with selectlib-4.14
//
//	AUTHOR:
//		U. Lammers (UL), Thu Oct 22 14:15:14 MET DST 1998
//
//	$Header: /usr/local/cvs/sasdev/task_devel/packages/xmmselect/src/XmmSelectGui.h,v 1.26 2002/09/18 15:24:16 ulammers Exp $
//
#ifndef XMM_SELECT_GUI_H
#define XMM_SELECT_GUI_H

#include <string>

#include <qpopupmenu.h>
#include <qgroupbox.h>
#include <qmenubar.h>
#include <qlineedit.h>

#if defined(DEBUG)
	#undef DEBUG
#endif

#include "SasTaskWindow.h"

class ColumnSelector;
class ExpressionConstructor;
class OnDemandScrollView;

class XmmSelectGui : public SasTaskWindow
{
	Q_OBJECT

public:
	XmmSelectGui(const char *name);
	//
	//	PURPOSE:
	//		Instantiate the XmmSelect main GUI - the exec() method
	//		runs it
	//
  

	bool showIntensityImage() const { return _showIntensityImage; }
	ExpressionConstructor *expressionConstructor()
	{ return _exprConstructor; }

	void presentDssImportDialog();
  
	void statusMessage(const QString &message) const;
	void statusMessage(const QString &message, unsigned time) const;
	void clearStatus() const;
  
	~XmmSelectGui();
		//
		//	PURPOSE:
		//		Destroys the XmmSelect main GUI and frees up all resources
		//

signals:
	void newTable(std::string newTableName);

private slots:
	void loadNewTable();
	void addAnyColumn();
	void addPhaseColumn();
	void deleteColumn();
	void updateColumnBox();
  
	//	methods bound to push buttons
	void filter();
	void image();
	void spectrum();
	void spectralProducts();
	void ratesCurve();
	void histogram();
	void readImageRegions();
	void readXyplotRegions();
	void unifyRegions();
	void intersectRegions();
	void binnedIntensityImage();
	void scatterPlotImage();
	void backscale();
	void eregionanalyse();

private:
	//	data members
	QWidget					*_central;
	QGroupBox				*_columnGroupBox;
	OnDemandScrollView		*_columnScrollView;
	QVBoxLayout				*_columnVbox;
	ColumnSelector			*_columnSelector;
	ExpressionConstructor	*_exprConstructor;
	bool					_imageUp;
	double					_binX, _binY;
	bool					_withMinX, _withMinY;
	double					_minX, _minY;
	double					_oneDmin, _oneDbin;
	bool					_withOneDmin;
	enum XyPlotType { Nothing, Spectrum, Rates, Histo };
	XyPlotType				_xyplotUp;
  
	//	methods
	void extractOneDproductAndDisplay(XyPlotType type);
	void		vboxsetup();
	QMenuBar	*setupMenuBar();
	QWidget		*setupExpressionWidget(QWidget *parent,
									   const std::string &expr = "");
	QWidget		*setupColumnBox(QWidget *parent,
								unsigned minColumns = 2);
	QWidget		*setupRegionSelection();
	QWidget		*setupBottomButtonRow();

	//	to treat multiple regions
	QPopupMenu		*_region, *_viewer, *_productProcess;
	int  _intersectRegionsId;
	int  _unifyRegionsId;
	int  _binnedIntensityImageId;
	int  _scatterPlotImageId;
	int	 _backscaleId;
	int	 _eregionId;
	bool _unifyRegions;
	bool _showIntensityImage;
	bool _runBackscale;
	bool _runRegionAnalyse;
}; // XmmSelectGui

#endif


