//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//				       (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	XmmSelectServer.cc --- implementation of central task server class
//
//	DESCRIPTION:
//		A central task resource server class is defined.
//
//	CHANGE HISTORY:
//		UL, 2000-10-17: 1.0.0: - first version
//		UL, 2000-11-07: 1.1.0: - some minor tweaks
//
//	AUTHOR:
//		U. Lammers (UL), Wed Oct 18 10:55:23 MET DST 2000
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /usr/local/cvs/sasdev/task_devel/packages/xmmselect/src/XmmSelectServer.cc,v 1.5 2002/07/11 16:08:13 ulammers Exp $
//

#include <qobject.h>
#include "XmmSelectServer.h"
#include "TaskPreferences.h"
#include "SelectError.h"
#include "Task.h"
#include "param.h"

using namespace std;

XmmSelectServer *XmmSelectServer::_instance = 0;

XmmSelectServer::XmmSelectServer()
	: _myPars(*Info::Task::current()->parameters())
{
	assert(!_instance);
	_instance = this;
	_prefs = new TaskPreferenceGroup(Info::Task::current()->name());
	_tableInquiry = new TableInquiry(_myPars["table"]->stringValue());
	_gui = new XmmSelectGui("XmmSelect");
	_gui->presentDssImportDialog();

	connect(_gui, SIGNAL(newTable(std::string)), this,
			SLOT(newTable(std::string)));

	//	enable exceptions in selectlib
	SelectError::selectErrorHandler.exceptions(true);
} // XmmSelectServer::XmmSelectServer()


void XmmSelectServer::newTable(string tableName)
{
	delete _tableInquiry;
	_tableInquiry = new TableInquiry(tableName);
	emit tableChanged();
	_gui->presentDssImportDialog();
} // XmmSelectServer::newTable()


void XmmSelectServer::reloadTable()
{
	newTable(_tableInquiry->name());
} // XmmSelectServer::XmmSelectServer()


XmmSelectServer::~XmmSelectServer()
{
	delete _tableInquiry; _tableInquiry = 0;
	delete _gui; _gui = 0;
	delete _prefs; _prefs = 0;
} // XmmSelectServer::~XmmSelectServer()


XmmSelectServer *XmmSelectServer::instance()
{
	return _instance;
} // XmmSelectServer::instance()
