//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//				       (c) 1997-2010 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	xmmselect.cc --- The GUI for the selection-extraction-viewing cycle
//
//	DESCRIPTION:
//		`xmmselect' is the GUI through which the SAS user controlls the
//		interactive selection-extraction-viewing cycle. It used the
//		tasks:
//			evselect	for	selection and product extraction
//			imgdislay	for	display of 2-D images in which the user
//						can mark regions which are read back
//			dsplot		for display of x-vs-y plots
//			tabcalc		for creation of new table columns (not implemented yet)
//
//		TBC.
//
//	CHANGE HISTORY:
//		UL, 1998-10-22: 0.1.0: - skeleton
//		UL, 1999-??-??: 1.0.0: - first working version
//		UL, 1999-??-??: 1.1.0: - support for taskmain, i.e., xmmselect is
//								 now a proper SAS task
//		UL, 1999-08-03: 1.2.0: - fixed core-dump problem on exit; was related
//								 to static instances of XmmSelectApp/Gui
//								 objects in xmmselectInit();
//		UL, 2000-10-06: 1.3.0: - added exception handling
//
//	AUTHOR:
//		U. Lammers (UL), Thu Oct 22 11:14:38 MET DST 1998
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /usr/local/cvs/sasdev/task_devel/packages/xmmselect/src/xmmselect.cc,v 1.8 2002/07/11 16:08:13 ulammers Exp $
//

#include <qmessagebox.h>
#include "ExceptionErrorHandler.h"
#include "Tracer.h"

#include "XmmSelectServer.h"
#include "xmmselect.h"

using namespace std;

void xmmselect()
{
	XmmSelectServer server;
	XmmSelectGui *g = server.gui();

	ExceptionErrorHandler local;
	ErrorHandler *oldHandler = errHandler.handler(&local);
	while (true) {
		try {
			g->exec();
			break;
		} catch (SasException::Exception e) {
			QMessageBox::warning(g, "An error has occured",
								 e.message.c_str(), "Ok");
		} catch (...) {
			errHandler.handler(oldHandler);
			errstr<<"Something catastrophic happened - please submit an SPR "
					"to the SOC describing exactly what you were doing."
				  <<Sas::fatal("UnknownFatalError");
		}
	}

    //  restore old error handler
    errHandler.handler(oldHandler);
} // xmmselect()
